package Catalyst::Controller::POD::Search;
use strict;
use warnings;
use JSON::XS;
use XML::Simple;
use URI;
use URI::QueryParam;
use LWP::UserAgent;
use base "Catalyst::Controller";
use base "Class::Accessor::Fast";


1;
